@@ -21,6 +21,8 @@
 #include "Python.h"
 #include <math.h>
 
+#define PYO_VERSION "0.6.2"
+
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
 
@@ -256,6 +258,7 @@ extern PyTypeObject PortType;
 extern PyTypeObject AllpassType;
 extern PyTypeObject Allpass2Type;
 extern PyTypeObject PhaserType;
+extern PyTypeObject VocoderType;
 extern PyTypeObject DenormType;
 extern PyTypeObject DistoType;
 extern PyTypeObject ClipType;
@@ -284,6 +287,7 @@ extern PyTypeObject HarmonizerType;
 
 extern PyTypeObject MidictlType;
 extern PyTypeObject CtlScanType;
+extern PyTypeObject CtlScan2Type;
 extern PyTypeObject MidiNoteType;
 extern PyTypeObject NoteinType;
 extern PyTypeObject BendinType;
@@ -326,6 +330,7 @@ extern PyTypeObject TrigTableRecType;
 extern PyTypeObject NewMatrixType;
 extern PyTypeObject MatrixPointerType;
 extern PyTypeObject MatrixRecType;
+extern PyTypeObject MatrixRecLoopType;
 extern PyTypeObject MatrixMorphType;
 
 extern PyTypeObject OscSendType;
@@ -482,28 +487,64 @@ extern PyTypeObject VectralType;
 
 /* VISIT & CLEAR */
 #define pyo_VISIT \
+    if (PyServer_get_server() != NULL) \
+        Py_VISIT(self->server); \
     Py_VISIT(self->stream); \
-    Py_VISIT(self->server); \
     Py_VISIT(self->mul); \
     Py_VISIT(self->mul_stream); \
     Py_VISIT(self->add); \
     Py_VISIT(self->add_stream);    
 
+#define pyo_table_VISIT \
+    if (PyServer_get_server() != NULL) \
+        Py_VISIT(self->server); \
+    Py_VISIT(self->tablestream); \
+
+#define pyo_matrix_VISIT \
+    if (PyServer_get_server() != NULL) \
+        Py_VISIT(self->server); \
+    Py_VISIT(self->matrixstream); \
+
 #define pyo_CLEAR \
+    if (PyServer_get_server() != NULL) { \
+        Py_INCREF(self->server); \
+        Py_CLEAR(self->server); \
+    } \
     Py_CLEAR(self->stream); \
-    Py_CLEAR(self->server); \
     Py_CLEAR(self->mul); \
     Py_CLEAR(self->mul_stream); \
     Py_CLEAR(self->add); \
-    Py_CLEAR(self->add_stream);    
+    Py_CLEAR(self->add_stream); \
 
-#define DELETE_STREAM \
-    Server_removeStream((Server *)self->server, Stream_getStreamId(self->stream)); \
-    Py_INCREF(Py_None); \
-    return Py_None;
+#define pyo_table_CLEAR \
+    if (PyServer_get_server() != NULL) { \
+        Py_INCREF(self->server); \
+        Py_CLEAR(self->server); \
+    } \
+    Py_CLEAR(self->tablestream); \
+
+#define pyo_matrix_CLEAR \
+    if (PyServer_get_server() != NULL) { \
+        Py_INCREF(self->server); \
+        Py_CLEAR(self->server); \
+    } \
+    Py_CLEAR(self->matrixstream); \
+
+#define pyo_DEALLOC \
+    if (PyServer_get_server() != NULL) \
+        Server_removeStream((Server *)self->server, Stream_getStreamId(self->stream)); \
+    free(self->data); \
 
 /* INIT INPUT STREAM */
 #define INIT_INPUT_STREAM \
+    if ( PyObject_HasAttrString((PyObject *)inputtmp, "server") == 0 ) { \
+        PySys_WriteStderr("TypeError: \"input\" argument must be a PyoObject.\n"); \
+        if (PyInt_AsLong(PyObject_CallMethod(self->server, "getIsBooted", NULL))) { \
+            PyObject_CallMethod(self->server, "shutdown", NULL); \
+        } \
+        Py_Exit(1); \
+    } \
+    Py_INCREF(inputtmp); \
     Py_XDECREF(self->input); \
     self->input = inputtmp; \
     input_streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getStream", NULL); \
@@ -512,6 +553,7 @@ extern PyTypeObject VectralType;
     self->input_stream = (Stream *)input_streamtmp;
 
 #define INIT_INPUT_TRIGGER_STREAM \
+    Py_INCREF(inputtmp); \
     Py_XDECREF(self->input); \
     self->input = inputtmp; \
     input_streamtmp = PyObject_CallMethod((PyObject *)self->input, "_getTriggerStream", NULL); \
@@ -519,6 +561,35 @@ extern PyTypeObject VectralType;
     Py_XDECREF(self->input_stream); \
     self->input_stream = (TriggerStream *)input_streamtmp;
 
+/* Init Server & Stream */
+#define INIT_OBJECT_COMMON \
+    self->server = PyServer_get_server(); \
+    self->mul = PyFloat_FromDouble(1); \
+    self->add = PyFloat_FromDouble(0); \
+    self->bufsize = PyInt_AsLong(PyObject_CallMethod(self->server, "getBufferSize", NULL)); \
+    self->sr = PyFloat_AsDouble(PyObject_CallMethod(self->server, "getSamplingRate", NULL)); \
+    self->nchnls = PyInt_AsLong(PyObject_CallMethod(self->server, "getNchnls", NULL)); \
+    self->data = (MYFLT *)realloc(self->data, (self->bufsize) * sizeof(MYFLT)); \
+    for (i=0; i<self->bufsize; i++) \
+        self->data[i] = 0.0; \
+    MAKE_NEW_STREAM(self->stream, &StreamType, NULL); \
+    Stream_setStreamObject(self->stream, (PyObject *)self); \
+    Stream_setStreamId(self->stream, Stream_getNewStreamId()); \
+    Stream_setBufferSize(self->stream, self->bufsize); \
+    Stream_setData(self->stream, self->data);
+
+#define SET_INTERP_POINTER \
+    if (self->interp == 0) \
+        self->interp = 2; \
+    if (self->interp == 1) \
+        self->interp_func_ptr = nointerp; \
+    else if (self->interp == 2) \
+        self->interp_func_ptr = linear; \
+    else if (self->interp == 3) \
+        self->interp_func_ptr = cosine; \
+    else if (self->interp == 4) \
+        self->interp_func_ptr = cubic; \
+
 /* Set data */
 #define SET_TABLE_DATA \
     int i; \
@@ -835,37 +906,6 @@ extern PyTypeObject VectralType;
  \
     return PyFloat_FromDouble(self->data[y][x]); \
 
-
-/* Init Server & Stream */
-#define INIT_OBJECT_COMMON \
-    self->server = PyServer_get_server(); \
-    self->mul = PyFloat_FromDouble(1); \
-    self->add = PyFloat_FromDouble(0); \
-    self->bufsize = PyInt_AsLong(PyObject_CallMethod(self->server, "getBufferSize", NULL)); \
-    self->sr = PyFloat_AsDouble(PyObject_CallMethod(self->server, "getSamplingRate", NULL)); \
-    self->nchnls = PyInt_AsLong(PyObject_CallMethod(self->server, "getNchnls", NULL)); \
-    self->data = (MYFLT *)realloc(self->data, (self->bufsize) * sizeof(MYFLT)); \
-    MAKE_NEW_STREAM(self->stream, &StreamType, NULL); \
-    Stream_setStreamObject(self->stream, (PyObject *)self); \
-    Stream_setStreamId(self->stream, Stream_getNewStreamId()); \
-    Stream_setBufferSize(self->stream, self->bufsize); \
-    for (i=0; i<self->bufsize; i++) \
-        self->data[i] = 0.0; \
-    Stream_setData(self->stream, self->data);
-
-
-#define SET_INTERP_POINTER \
-    if (self->interp == 0) \
-        self->interp = 2; \
-    if (self->interp == 1) \
-        self->interp_func_ptr = nointerp; \
-    else if (self->interp == 2) \
-        self->interp_func_ptr = linear; \
-    else if (self->interp == 3) \
-        self->interp_func_ptr = cosine; \
-    else if (self->interp == 4) \
-        self->interp_func_ptr = cubic; \
-
 /* GETS & SETS */
 #define GET_SERVER \
     if (self->server == NULL) { \
@@ -1040,14 +1080,11 @@ extern PyTypeObject VectralType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setMul", "O", arg); \
-    Py_INCREF(self); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
-    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_MULTIPLY \
     PyObject_CallMethod((PyObject *)self, "setMul", "O", arg); \
-    Py_INCREF(self); \
     return (PyObject *)self;
 
 #define ADD \
@@ -1055,14 +1092,11 @@ extern PyTypeObject VectralType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setAdd", "O", arg); \
-    Py_INCREF(self); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
-    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_ADD \
     PyObject_CallMethod((PyObject *)self, "setAdd", "O", arg); \
-    Py_INCREF(self); \
     return (PyObject *)self;
 
 #define SUB \
@@ -1070,14 +1104,11 @@ extern PyTypeObject VectralType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setSub", "O", arg); \
-    Py_INCREF(self); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
-    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_SUB \
     PyObject_CallMethod((PyObject *)self, "setSub", "O", arg); \
-    Py_INCREF(self); \
     return (PyObject *)self;
 
 #define DIV \
@@ -1085,14 +1116,11 @@ extern PyTypeObject VectralType;
     MAKE_NEW_DUMMY(dummy, &DummyType, NULL); \
     Dummy_initialize(dummy); \
     PyObject_CallMethod((PyObject *)dummy, "setDiv", "O", arg); \
-    Py_INCREF(self); \
     PyObject_CallMethod((PyObject *)dummy, "setInput", "O", self); \
-    Py_INCREF(dummy); \
     return (PyObject *)dummy;
 
 #define INPLACE_DIV \
     PyObject_CallMethod((PyObject *)self, "setDiv", "O", arg); \
-    Py_INCREF(self); \
     return (PyObject *)self;
 
 /* PLAY, OUT, STOP */
