@@ -23,17 +23,15 @@ import random, os, sys, inspect, tempfile
 from subprocess import call
 from distutils.sysconfig import get_python_lib
 
-PYO_VERSION = '0.6.1'
+PYO_VERSION = '0.6.2'
 
 import __builtin__
 if hasattr(__builtin__, 'pyo_use_double'):
     import pyo64 as current_pyo
     from _pyo64 import *
-    print "pyo version %s (uses double precision)" % PYO_VERSION
 else:    
     import pyo as current_pyo
     from _pyo import *
-    print "pyo version %s (uses single precision)" % PYO_VERSION
     
 from _maps import *
 from _widgets import createCtrlWindow, createViewTableWindow, createViewMatrixWindow
@@ -101,7 +99,7 @@ def wrap(arg, i):
         return x
 
 if sys.version_info[:2] <= (2, 5):
-    def example(cls, dur=5):
+    def example(cls, dur=5, toprint=True, double=False):
         """
     Execute the example given in the documentation of the object as an argument.
 
@@ -113,16 +111,29 @@ if sys.version_info[:2] <= (2, 5):
         Class reference of the desired object example.
     dur : float, optional
         Duration of the example.
+    toprint : boolean, optional
+        If True, the example script will be printed to the console.
+        Defaults to True.
+    double : boolean, optional
+        If True, force the example to run in double precision (64-bit)
+        Defaults to False.
 
     Examples:
 
     >>> example(Sine)
 
         """
-        doc = cls.__doc__.split("Examples:")[1]
-        lines = doc.splitlines()
+        doc = cls.__doc__.split("Examples:")
+        if len(doc) < 2:
+            print "There is no manual example for %s object." % cls.__name__
+            return
+        if "Server" in doc[1]:
+            with_server = True
+        else:
+            with_server = False
+        lines = doc[1].splitlines()
         ex_lines = [line.lstrip("    ") for line in lines if ">>>" in line or "..." in line]
-        if hasattr(__builtin__, 'pyo_use_double'):
+        if hasattr(__builtin__, 'pyo_use_double') or double:
             ex = "import time\nfrom pyo64 import *\n"
         else:
             ex = "import time\nfrom pyo import *\n"
@@ -130,14 +141,16 @@ if sys.version_info[:2] <= (2, 5):
             if ">>>" in line: line = line.lstrip(">>> ")
             if "..." in line: line = "    " +  line.lstrip("... ")
             ex += line + "\n"
-        ex += "time.sleep(%f)\ns.stop()\ntime.sleep(0.25)\ns.shutdown()\n" % dur
+        if with_server:
+            ex += "time.sleep(%f)\ns.stop()\ntime.sleep(0.25)\ns.shutdown()\n" % dur
         f = open('/tmp/pyo_example.py', 'w')
-        f.write('print """\n%s\n"""\n' % ex)
+        if toprint:
+            f.write('print """\n%s\n"""\n' % ex)
         f.write(ex)
         f.close()    
         p = call(["python", '/tmp/pyo_example.py'])
 else:
-    def example(cls, dur=5):
+    def example(cls, dur=5, toprint=True, double=False):
         """
     Execute the example given in the documentation of the object as an argument.
 
@@ -149,16 +162,29 @@ else:
         Class reference of the desired object example.
     dur : float, optional
         Duration of the example.
+    toprint : boolean, optional
+        If True, the example script will be printed to the console.
+        Defaults to True.
+    double : boolean, optional
+        If True, force the example to run in double precision (64-bit)
+        Defaults to False.
 
     Examples:
 
     >>> example(Sine)
 
         """
-        doc = cls.__doc__.split("Examples:")[1]
-        lines = doc.splitlines()
+        doc = cls.__doc__.split("Examples:")
+        if len(doc) < 2:
+            print "There is no manual example for %s object." % cls.__name__
+            return
+        if "Server" in doc[1]:
+            with_server = True
+        else:
+            with_server = False
+        lines = doc[1].splitlines()
         ex_lines = [line.lstrip("    ") for line in lines if ">>>" in line or "..." in line]
-        if hasattr(__builtin__, 'pyo_use_double'):
+        if hasattr(__builtin__, 'pyo_use_double') or double:
             ex = "import time\nfrom pyo64 import *\n"
         else:
             ex = "import time\nfrom pyo import *\n"
@@ -166,9 +192,11 @@ else:
             if ">>>" in line: line = line.lstrip(">>> ")
             if "..." in line: line = "    " +  line.lstrip("... ")
             ex += line + "\n"
-        ex += "time.sleep(%f)\ns.stop()\ntime.sleep(0.25)\ns.shutdown()\n" % dur
+        if with_server:
+            ex += "time.sleep(%f)\ns.stop()\ntime.sleep(0.25)\ns.shutdown()\n" % dur
         f = tempfile.NamedTemporaryFile(delete=False)
-        f.write('print """\n%s\n"""\n' % ex)
+        if toprint:
+            f.write('print """\n%s\n"""\n' % ex)
         f.write(ex)
         f.close()    
         p = call(["python", f.name])
@@ -268,6 +296,10 @@ class PyoObject(object):
     ctrl(map_list, title) : Opens a sliders window to control parameters.
     get(all) : Return the first sample of the current buffer as a float.
     dump() : Print current status of the object's attributes.
+    getBaseObjects() : Return a list of audio Stream objects managed by the instance.
+    isPlaying(all) : Returns True if the object is playing, otherwise, returns False.
+    isOutputting(all) : Returns True if the object is sending samples to dac, 
+        otherwise, returns False.
 
     Attributes:
 
@@ -307,20 +339,14 @@ class PyoObject(object):
             if not serverBooted():
                 print "\nPYO Error: The Server must be booted before creating any audio object.\n"
                 exit()
-
         self._target_dict = {}
         self._signal_dict = {}
         self._keep_trace = []
         self._mul = 1.0
         self._add = 0.0
-        self._mul_dummy_keep_trace = []
-        self._add_dummy_keep_trace = []
-        self._div_upsamp_keep_trace = []
-        self._sub_upsamp_keep_trace = []
         self._op_duplicate = 1
 
     def __add__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             _add_dummy = Dummy([obj + wrap(x,i/self._op_duplicate) for i, obj in enumerate(self._base_objs)])
@@ -329,17 +355,16 @@ class PyoObject(object):
                 _add_dummy = x + self
             else:
                 _add_dummy = Dummy([wrap(self._base_objs,i) + obj for i, obj in enumerate(x)])
-        self._add_dummy_keep_trace.append(_add_dummy)
+        self._keep_trace.append(_add_dummy)
         return _add_dummy
         
     def __radd__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             _add_dummy = Dummy([obj + wrap(x,i/self._op_duplicate) for i, obj in enumerate(self._base_objs)])
         else:
             _add_dummy = Dummy([wrap(self._base_objs,i) + obj for i, obj in enumerate(x)])                
-        self._add_dummy_keep_trace.append(_add_dummy)
+        self._keep_trace.append(_add_dummy)
         return _add_dummy
             
     def __iadd__(self, x):
@@ -347,38 +372,34 @@ class PyoObject(object):
         return self
 
     def __sub__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             _add_dummy = Dummy([obj - wrap(x,i/self._op_duplicate) for i, obj in enumerate(self._base_objs)])
         else:
             if isinstance(x, PyoObject):
-                print 'Substraction Warning: %s - %s' % (self.__repr__(), x.__repr__()),
-                print 'Right operator trunctaded to match left operator number of streams.'
-                _add_dummy = Dummy([obj - wrap(x,i) for i, obj in enumerate(self._base_objs)])
+                _add_dummy = Dummy([wrap(self._base_objs,i) - wrap(x,i) for i in range(lmax)])
             else:
                 _add_dummy = Dummy([wrap(self._base_objs,i) - obj for i, obj in enumerate(x)])
-        self._add_dummy_keep_trace.append(_add_dummy)
+        self._keep_trace.append(_add_dummy)
         return _add_dummy
 
     def __rsub__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             tmp = []
             for i, obj in enumerate(self._base_objs):
                 sub_upsamp = Sig(wrap(x, i/self._op_duplicate))
-                self._sub_upsamp_keep_trace.append(sub_upsamp)
+                self._keep_trace.append(sub_upsamp)
                 tmp.append(sub_upsamp - obj)
             _add_dummy = Dummy(tmp)
         else:
             tmp = []
             for i, obj in enumerate(x):
                 sub_upsamp = Sig(obj)
-                self._sub_upsamp_keep_trace.append(sub_upsamp)
+                self._keep_trace.append(sub_upsamp)
                 tmp.append(sub_upsamp - wrap(self._base_objs,i))
             _add_dummy = Dummy(tmp)
-        self._add_dummy_keep_trace.append(_add_dummy)
+        self._keep_trace.append(_add_dummy)
         return _add_dummy
 
     def __isub__(self, x):
@@ -386,26 +407,24 @@ class PyoObject(object):
         return self
  
     def __mul__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             _mul_dummy = Dummy([obj * wrap(x,i/self._op_duplicate) for i, obj in enumerate(self._base_objs)])
         else:
             if isinstance(x, PyoObject):
-                _mul_dummy = x * self 
+                _mul_dummy = x * self
             else:
                 _mul_dummy = Dummy([wrap(self._base_objs,i) * obj for i, obj in enumerate(x)])  
-        self._mul_dummy_keep_trace.append(_mul_dummy)
+        self._keep_trace.append(_mul_dummy)
         return _mul_dummy
         
     def __rmul__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             _mul_dummy = Dummy([obj * wrap(x,i/self._op_duplicate) for i, obj in enumerate(self._base_objs)])
         else:
             _mul_dummy = Dummy([wrap(self._base_objs,i) * obj for i, obj in enumerate(x)])                
-        self._mul_dummy_keep_trace.append(_mul_dummy)
+        self._keep_trace.append(_mul_dummy)
         return _mul_dummy
             
     def __imul__(self, x):
@@ -413,38 +432,34 @@ class PyoObject(object):
         return self
  
     def __div__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             _mul_dummy = Dummy([obj / wrap(x,i/self._op_duplicate) for i, obj in enumerate(self._base_objs)])
         else:
             if isinstance(x, PyoObject):
-                print 'Division Warning: %s / %s' % (self.__repr__(), x.__repr__()),
-                print 'Right operator trunctaded to match left operator number of streams.'
-                _mul_dummy = Dummy([obj / wrap(x,i) for i, obj in enumerate(self._base_objs)])
+                _mul_dummy = Dummy([wrap(self._base_objs,i) / wrap(x,i) for i in range(lmax)])
             else:
                 _mul_dummy = Dummy([wrap(self._base_objs,i) / obj for i, obj in enumerate(x)])
-        self._mul_dummy_keep_trace.append(_mul_dummy)
+        self._keep_trace.append(_mul_dummy)
         return _mul_dummy
 
     def __rdiv__(self, x):
-        self._keep_trace.append(x)
         x, lmax = convertArgsToLists(x)
         if self.__len__() >= lmax:
             tmp = []
             for i, obj in enumerate(self._base_objs):
                 div_upsamp = Sig(wrap(x, i/self._op_duplicate))
-                self._div_upsamp_keep_trace.append(div_upsamp)
+                self._keep_trace.append(div_upsamp)
                 tmp.append(div_upsamp / obj)
             _mul_dummy = Dummy(tmp)
         else:
             tmp = []
             for i, obj in enumerate(x):
                 div_upsamp = Sig(obj)
-                self._div_upsamp_keep_trace.append(div_upsamp)
+                self._keep_trace.append(div_upsamp)
                 tmp.append(div_upsamp / wrap(self._base_objs,i))
             _mul_dummy = Dummy(tmp)
-        self._mul_dummy_keep_trace.append(_mul_dummy)
+        self._keep_trace.append(_mul_dummy)
         return _mul_dummy
 
     def __idiv__(self, x):
@@ -454,58 +469,56 @@ class PyoObject(object):
     def __getitem__(self, i):
         if i == 'trig':
             return self._trig_objs
-
         if type(i) == SliceType or i < len(self._base_objs):
             return self._base_objs[i]
         else:
             if type(i) == StringType:
                 print "Object %s has no stream named '%s'!" % (self.__class__, i)
             else:
-                print "'i' too large!"         
+                print "'i' too large in slicing object %s!" % self.__class__.__name__
  
     def __len__(self):
         return len(self._base_objs)
 
-    def __del__(self):
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
-
-        if hasattr(self, "_trig_objs"):
-            del self._trig_objs
-
-        if hasattr(self, "_input"):
-            if type(self._input) == ListType:
-                for pyoObj in self._input:
-                    if hasattr(pyoObj, "getBaseObjects"):
-                        for obj in pyoObj.getBaseObjects():
-                            obj.deleteStream()
-                            del obj
-            else:
-                if hasattr(self._input, "getBaseObjects"):
-                    for obj in self._input.getBaseObjects():
-                        obj.deleteStream()
-                        del obj
-            del self._input
-
-        for key in self.__dict__.keys():
-            if isinstance(self.__dict__[key], PyoObject):
-                del self.__dict__[key]
-            elif type(self.__dict__[key]) == ListType:
-                for ele in self.__dict__[key]:
-                    if hasattr(ele, "getBaseObjects"):
-                        for obj in ele.getBaseObjects():
-                            obj.deleteStream()
-                            del obj
-                    else:
-                        del ele
-
-        if hasattr(self, "_in_fader"):
-            del self._in_fader
-
     def __repr__(self):
         return '< Instance of %s class >' % self.__class__.__name__
-        
+    
+    def isPlaying(self, all=False):
+        """
+        Returns True if the object is playing, otherwise, returns False.
+
+        Parameters:
+
+            all : boolean, optional
+                If True, the object returns a list with the state of all
+                streams managed by the object. If False, it return a 
+                boolean corresponding to the state of the first stream.
+                Defaults to False.
+
+        """
+        if all:
+            return [obj._getStream().isPlaying() for obj in self._base_objs]
+        else:
+            return self._base_objs[0]._getStream().isPlaying()
+
+    def isOutputting(self, all=False):
+        """
+        Returns True if the object is sending samples to dac, otherwise, returns False.
+
+        Parameters:
+
+            all : boolean, optional
+                If True, the object returns a list with the state of all
+                streams managed by the object. If False, it return a 
+                boolean corresponding to the state of the first stream.
+                Defaults to False.
+
+        """
+        if all:
+            return [obj._getStream().isOutputting() for obj in self._base_objs]
+        else:
+            return self._base_objs[0]._getStream().isOutputting()
+
     def dump(self):
         """
         Print the number of streams and the current status of the 
@@ -539,7 +552,7 @@ class PyoObject(object):
                 will be returned as a list. Otherwise, only the value
                 of the first object's stream will be returned as a float.
                 Defaults to False.
-                 
+
         """
         if not all:
             return self._base_objs[0]._getStream().getValue()
@@ -548,7 +561,7 @@ class PyoObject(object):
             
     def getBaseObjects(self):
         """
-        Return a list of audio Stream objects.
+        Return a list of audio Stream objects managed by the instance.
         
         """
         return self._base_objs
@@ -573,7 +586,9 @@ class PyoObject(object):
         dur, delay, lmax = convertArgsToLists(dur, delay)
         if hasattr(self, "_trig_objs"):
             self._trig_objs.play(dur, delay)
-        self._base_objs = [obj.play(wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
+        if hasattr(self, "_base_players"):
+            [obj.play(wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_players)]
+        [obj.play(wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
         return self
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
@@ -611,13 +626,15 @@ class PyoObject(object):
         dur, delay, lmax = convertArgsToLists(dur, delay)
         if hasattr(self, "_trig_objs"):
             self._trig_objs.play(dur, delay)
+        if hasattr(self, "_base_players"):
+            [obj.play(wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_players)]
         if type(chnl) == ListType:
-            self._base_objs = [obj.out(wrap(chnl,i), wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
+            [obj.out(wrap(chnl,i), wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
         else:
             if chnl < 0:    
-                self._base_objs = [obj.out(i*inc, wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(random.sample(self._base_objs, len(self._base_objs)))]
+                [obj.out(i*inc, wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(random.sample(self._base_objs, len(self._base_objs)))]
             else:
-                self._base_objs = [obj.out(chnl+i*inc, wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
+                [obj.out(chnl+i*inc, wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
         return self
     
     def stop(self):
@@ -630,6 +647,8 @@ class PyoObject(object):
         """
         if hasattr(self, "_trig_objs"):
             self._trig_objs.stop()
+        if hasattr(self, "_base_players"):
+            [obj.stop() for obj in self._base_players]
         [obj.stop() for obj in self._base_objs]
         return self
 
@@ -728,7 +747,7 @@ class PyoObject(object):
 
         x : float or PyoObject
             New inversed `add` attribute.
-        
+
         """
         self._mul = x
         x, lmax = convertArgsToLists(x)
@@ -737,11 +756,11 @@ class PyoObject(object):
     def set(self, attr, value, port=0.025):
         """
         Replace any attribute with portamento.
-        
+
         This method is intended to be applied on attributes that are not
         already assigned to PyoObjects. It will work only with floats or
         list of floats.
-                
+
         Parameters:
 
         attr : string
@@ -750,16 +769,22 @@ class PyoObject(object):
             New value.
         port : float, optional
             Time, in seconds, to reach the new value
-        
+
         """
         self._target_dict[attr] = value
-        self._signal_dict[attr] = VarPort(value, port, getattr(self, attr), self._reset_from_set, attr)
+        init = getattr(self, attr)
+        if self._signal_dict.has_key(attr):
+            if isinstance(self._signal_dict[attr], VarPort):
+                if self._signal_dict[attr].isPlaying():
+                    init = self._signal_dict[attr].get(True)
+                    self._signal_dict[attr].stop()
+        self._signal_dict[attr] = VarPort(value, port, init, self._reset_from_set, attr)
         setattr(self, attr, self._signal_dict[attr])
 
     def _reset_from_set(self, attr=None):
-        setattr(self, attr, self._target_dict[attr])
+        if isinstance(getattr(self, attr), VarPort):
+            setattr(self, attr, self._target_dict[attr])
         self._signal_dict[attr].stop()
-        del self._signal_dict[attr]
         
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         """
@@ -769,7 +794,7 @@ class PyoObject(object):
 
         If a list of values are given to a parameter, a multisliders 
         will be used to control each stream independently.
-        
+
         Parameters:
 
         map_list : list of SLMap objects, optional
@@ -790,7 +815,6 @@ class PyoObject(object):
         if map_list == []:
             print("There is no controls for %s object." % self.__class__.__name__)
             return
-    
         createCtrlWindow(self, map_list, title, wxnoserver)
 
     @property
@@ -823,7 +847,7 @@ class PyoTableObject(object):
     getSize() : Return table size in samples.
     view() : Opens a window showing the contents of the table.
     dump() : Print current status of the object's attributes.
-    save(path, format) : Writes the content of the table in an audio file.
+    save(path, format, sampletype) : Writes the content of the table in an audio file.
     write(path, oneline) : Writes the content of the table in a text file.
     read(path) : Sets the content of the table from a text file.
     normalize() : Normalize table samples between -1 and 1.
@@ -832,6 +856,7 @@ class PyoTableObject(object):
     copy() : Returns a deep copy of the object.
     put(value, pos) : Puts a value at specified position in the table.
     get(pos) : Returns the value at specified position in the table.
+    getBaseObjects() : Return a list of table Stream objects managed by the instance.
     
     Notes:
     
@@ -855,7 +880,7 @@ class PyoTableObject(object):
         if i < len(self._base_objs):
             return self._base_objs[i]
         else:
-            print "'i' too large!"
+            print "'i' too large in slicing table %s!" % self.__class__.__name__
  
     def __len__(self):
         return len(self._base_objs)
@@ -904,12 +929,7 @@ class PyoTableObject(object):
                 4 : 64 bit float
 
         """
-        sr = int(self._base_objs[0].getServer().getSamplingRate())
-        if len(self._base_objs) == 1:
-            samples = self._base_objs[0].getTable()
-        else:
-            samples = [obj.getTable() for i, obj in enumerate(self._base_objs)]
-        savefile(samples, path, sr, len(self._base_objs), format, sampletype)
+        savefileFromTable(self, path, format, sampletype)
     
     def write(self, path, oneline=True):
         """
@@ -966,7 +986,7 @@ class PyoTableObject(object):
         
     def getBaseObjects(self):
         """
-        Return a list of table Stream objects.
+        Return a list of table Stream objects managed by the instance.
         
         """
         return self._base_objs
@@ -1048,7 +1068,6 @@ class PyoTableObject(object):
             _size = self.getSize()
             if type(_size) != ListType:
                 _size = [_size]
-
             _chnls = len(self._base_objs)
             args[0] = None
             args.append(_chnls)
@@ -1102,6 +1121,7 @@ class PyoMatrixObject(object):
     boost(min, max, boost) : Boost the contrast of values in the matrix.
     put(value, x, y) : Puts a value at specified position in the matrix.
     get(x, y) : Returns the value at specified position in the matrix.
+    getBaseObjects() : Returns a list of matrix stream objects managed by the instance.
     
     Notes:
     
@@ -1125,7 +1145,7 @@ class PyoMatrixObject(object):
         if i < len(self._base_objs):
             return self._base_objs[i]
         else:
-            print "'i' too large!"
+            print "'i' too large in slicing matrix %s!" % self.__class__.__name__
  
     def __len__(self):
         return len(self._base_objs)
@@ -1185,7 +1205,7 @@ class PyoMatrixObject(object):
         
     def getBaseObjects(self):
         """
-        Returns a list of matrix stream objects.
+        Returns a list of matrix stream objects managed by the instance.
         
         """
         return self._base_objs
@@ -1361,22 +1381,6 @@ class Mix(PyoObject):
     def __dir__(self):
         return ['mul', 'add']
 
-    def __del__(self):
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
-        del self._base_objs
-        if type(self._input) == ListType:
-            for pyoObj in self._input:
-                for obj in pyoObj.getBaseObjects():
-                    obj.deleteStream()
-                    del obj
-        else:
-            for obj in self._input.getBaseObjects():
-                obj.deleteStream()
-                del obj
-        del self._input
-
 class Dummy(PyoObject):
     """
     Dummy object used to perform arithmetics on PyoObject.
@@ -1435,11 +1439,6 @@ class Dummy(PyoObject):
 
     def __dir__(self):
         return ['mul', 'add']
-
-    def deleteStream(self):
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
         
 class InputFader(PyoObject):
     """
@@ -1622,7 +1621,7 @@ class VarPort(PyoObject):
     >>> def callback(arg):
     ...     print "end of line"
     ...     print arg
-    .... 
+    ... 
     >>> fr = VarPort(value=500, time=2, init=250, function=callback, arg="YEP!")
     >>> a = SineLoop(freq=[fr,fr*1.01], feedback=0.05, mul=.2).out()
 
