@@ -28,10 +28,11 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
+import sys
 from _core import *
 from _maps import *
 from _widgets import createGraphWindow
-from types import ListType
+from types import ListType, TupleType
 
 ######################################################################
 ### Controls
@@ -103,7 +104,7 @@ class Fader(PyoObject):
         return ['fadein', 'fadeout', 'dur', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setFadein(self, x):
         """
@@ -262,7 +263,7 @@ class Adsr(PyoObject):
         return ['attack', 'decay', 'sustain', 'release', 'dur', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setAttack(self, x):
         """
@@ -423,6 +424,12 @@ class Linseg(PyoObject):
     """
     def __init__(self, list, loop=False, initToFirstVal=False, mul=1, add=0):
         PyoObject.__init__(self)
+        if type(list) != ListType:
+            print >> sys.stderr, 'TypeError: "list" argument of %s must be a list of tuples.\n' % self.__class__.__name__
+            exit()
+        if type(list[0]) != TupleType:
+            print >> sys.stderr, 'TypeError: "list" argument of %s must be a list of tuples.\n' % self.__class__.__name__
+            exit()
         self._list = list
         self._loop = loop
         self._mul = mul
@@ -439,7 +446,7 @@ class Linseg(PyoObject):
         return ['list', 'loop', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setList(self, x):
         """
@@ -607,6 +614,12 @@ class Expseg(PyoObject):
     """
     def __init__(self, list, loop=False, exp=10, inverse=True, initToFirstVal=False, mul=1, add=0):
         PyoObject.__init__(self)
+        if type(list) != ListType:
+            print >> sys.stderr, 'TypeError: "list" argument of %s must be a list of tuples.\n' % self.__class__.__name__
+            exit()
+        if type(list[0]) != TupleType:
+            print >> sys.stderr, 'TypeError: "list" argument of %s must be a list of tuples.\n' % self.__class__.__name__
+            exit()
         self._list = list
         self._loop = loop
         self._exp = exp
@@ -625,7 +638,7 @@ class Expseg(PyoObject):
         return ['list', 'loop', 'exp', 'inverse', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setList(self, x):
         """
