@@ -27,6 +27,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
+import sys
 from _core import *
 from _maps import *
 
@@ -102,7 +103,7 @@ class Midictl(PyoObject):
         return ['ctlnumber', 'minscale', 'maxscale', 'channel', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setCtlNumber(self, x):
         """
@@ -259,6 +260,9 @@ class CtlScan(PyoObject):
     """
     def __init__(self, function, toprint=True):
         PyoObject.__init__(self)
+        if not callable(function):
+            print >> sys.stderr, 'TypeError: "function" argument of %s must be callable.\n' % self.__class__.__name__
+            exit()
         self._function = function
         self._toprint = toprint
         self._base_objs = [CtlScan_base(self._function, self._toprint)]
@@ -267,7 +271,123 @@ class CtlScan(PyoObject):
         return []
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
+
+    def setMul(self, x):
+        pass
+
+    def setAdd(self, x):
+        pass
+
+    def setSub(self, x):
+        pass
+
+    def setDiv(self, x):
+        pass
+
+    def setFunction(self, x):
+        """
+        Replace the `function` attribute.
+
+        Parameters:
+
+        x : Python function
+            new `function` attribute.
+
+        """
+        self._function = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setFunction(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setToprint(self, x):
+        """
+        Replace the `toprint` attribute.
+
+        Parameters:
+
+        x : int
+            new `toprint` attribute.
+
+        """
+        self._toprint = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setToprint(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = []
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+
+    @property
+    def function(self): return self._function
+    @function.setter
+    def function(self, x): self.setFunction(x)   
+    @property
+    def toprint(self): return self._toprint
+    @toprint.setter
+    def toprint(self, x): self.setToprint(x)   
+
+class CtlScan2(PyoObject):
+    """
+    Scan the Midi channel and controller number in input.
+
+    Scan the Midi channel and controller number in input and send them 
+    to a standard python `function`. Useful to implement a MidiLearn 
+    algorithm.
+
+    Parentclass: PyoObject
+
+    Parameters:
+
+    function : Python function
+        Function to be called. The function must be declared
+        with two arguments, one for the controller number and 
+        one for the midi channel. Ex.: 
+        def ctl_scan(ctlnum, midichnl):
+            print ctlnum, midichnl
+    toprint : boolean, optional
+        If True, controller number and value will be print to 
+        the console.
+
+    Methods:
+
+    setFunction(x) : Replace the `function` attribute.
+    setToprint(x) : Replace the `toprint` attribute.
+
+    Attributes:
+
+    function : Python function. Function to be called.
+    toprint : boolean. If True, print values to the console.
+
+    Notes:
+
+    The out() method is bypassed. CtlScan2's signal can not be sent 
+    to audio outs.
+
+    Examples:
+
+    >>> s = Server()
+    >>> s.setMidiInputDevice(0) # enter your device number (see pm_list_devices())
+    >>> s.boot()
+    >>> s.start()
+    >>> def ctl_scan(ctlnum, midichnl):
+    ...     print ctlnum, midichnl
+    >>> a = CtlScan2(ctl_scan)
+
+    """
+    def __init__(self, function, toprint=True):
+        PyoObject.__init__(self)
+        if not callable(function):
+            print >> sys.stderr, 'TypeError: "function" argument of %s must be callable.\n' % self.__class__.__name__
+            exit()
+        self._function = function
+        self._toprint = toprint
+        self._base_objs = [CtlScan2_base(self._function, self._toprint)]
+
+    def __dir__(self):
+        return []
+
+    def out(self, chnl=0, inc=1, dur=0, delay=0):
+        return self.play(dur, delay)
 
     def setMul(self, x):
         pass
@@ -405,19 +525,6 @@ class Notein(PyoObject):
     def __dir__(self):
         return ['channel', 'mul', 'add']
 
-    def __del__(self):
-        if self._pitch_dummy:
-            [obj.deleteStream() for obj in self._pitch_dummy]
-        if self._velocity_dummy:
-            [obj.deleteStream() for obj in self._velocity_dummy]
-        self._pitch_dummy = []
-        self._velocity_dummy = []
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
-        self._base_handler.deleteStream()
-        del self._base_handler
-
     def __getitem__(self, str):
         if str == 'pitch':
             self._pitch_dummy.append(Dummy([self._base_objs[i*2] for i in range(self._poly)]))
@@ -482,17 +589,14 @@ class Notein(PyoObject):
                         
     def play(self, dur=0, delay=0):
         self._base_handler.play()
-        dur, delay, lmax = convertArgsToLists(dur, delay)
-        self._base_objs = [obj.play(wrap(dur,i), wrap(delay,i)) for i, obj in enumerate(self._base_objs)]
-        return self
+        return PyoObject.play(self, dur, delay)
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
-    
+        return self.play(dur, delay)
+
     def stop(self):
         self._base_handler.stop()
-        [obj.stop() for obj in self._base_objs]
-        return self
+        return PyoObject.stop(self)
 
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = []
@@ -567,7 +671,7 @@ class Bendin(PyoObject):
         return ['brange', 'scale', 'channel', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setBrange(self, x):
         """
@@ -699,7 +803,7 @@ class Touchin(PyoObject):
         return ['minscale', 'maxscale', 'channel', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setMinScale(self, x):
         """
@@ -812,7 +916,7 @@ class Programin(PyoObject):
         return ['channel', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setChannel(self, x):
         """
@@ -924,7 +1028,7 @@ class MidiAdsr(PyoObject):
         return ['input', 'attack', 'decay', 'sustain', 'release', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setInput(self, x, fadetime=0.05):
         """
@@ -1123,7 +1227,7 @@ class MidiDelAdsr(PyoObject):
         return ['input', 'delay', 'attack', 'decay', 'sustain', 'release', 'mul', 'add']
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setInput(self, x, fadetime=0.05):
         """
