@@ -31,8 +31,10 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
+import sys
 from _core import *
 from _maps import *
+from types import IntType
 
 ######################################################################
 ### Open Sound Control
@@ -106,7 +108,7 @@ class OscSend(PyoObject):
         self._in_fader.setInput(x, fadetime)
             
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setMul(self, x):
         pass
@@ -176,6 +178,9 @@ class OscReceive(PyoObject):
 
     def __init__(self, port, address, mul=1, add=0):
         PyoObject.__init__(self)
+        if type(port) != IntType:
+            print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
+            exit()
         self._mul = mul
         self._add = add
         address, mul, add, lmax = convertArgsToLists(address, mul, add)
@@ -185,14 +190,6 @@ class OscReceive(PyoObject):
 
     def __dir__(self):
         return ['mul', 'add']
-
-    def __del__(self):
-        self._mainReceiver.free_port()
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
-        self._mainReceiver.deleteStream()
-        del self._mainReceiver
             
     def __getitem__(self, i):
         if type(i) == type(''):
@@ -247,7 +244,6 @@ class OscReceive(PyoObject):
         for ind in reversed(indexes):
             self._address.pop(ind)
             obj = self._base_objs.pop(ind)
-            obj.deleteStream()
 
     def setInterpolation(self, x):
         """
@@ -289,7 +285,7 @@ class OscReceive(PyoObject):
             return [obj._getStream().getValue() for obj in self._base_objs]
              
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = []
@@ -369,7 +365,7 @@ class OscDataSend(PyoObject):
         return []
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def setMul(self, x):
         pass
@@ -516,7 +512,13 @@ class OscDataReceive(PyoObject):
 
     def __init__(self, port, address, function, mul=1, add=0):
         PyoObject.__init__(self)
+        if type(port) != IntType:
+            print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
+            exit()
         self._port = port
+        if not callable(function):
+            print >> sys.stderr, 'TypeError: "function" argument of %s must be callable.\n' % self.__class__.__name__
+            exit()
         self._function = function
         self._address, lmax = convertArgsToLists(address)
         # self._address is linked with list at C level
@@ -525,14 +527,8 @@ class OscDataReceive(PyoObject):
     def __dir__(self):
         return []
 
-    def __del__(self):
-        self._base_objs[0].free_port()
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def getAddresses(self):
         """
@@ -632,6 +628,12 @@ class OscListReceive(PyoObject):
 
     def __init__(self, port, address, num=8, mul=1, add=0):
         PyoObject.__init__(self)
+        if type(port) != IntType:
+            print >> sys.stderr, 'TypeError: "port" argument of %s must be an integer.\n' % self.__class__.__name__
+            exit()
+        if type(num) != IntType:
+            print >> sys.stderr, 'TypeError: "num" argument of %s must be an integer.\n' % self.__class__.__name__
+            exit()
         self._num = num
         self._op_duplicate = self._num
         self._mul = mul
@@ -644,14 +646,6 @@ class OscListReceive(PyoObject):
     def __dir__(self):
         return ['mul', 'add']
 
-    def __del__(self):
-        self._mainReceiver.free_port()
-        for obj in self._base_objs:
-            obj.deleteStream()
-            del obj
-        self._mainReceiver.deleteStream()
-        del self._mainReceiver
-
     def __getitem__(self, i):
         if type(i) == type(''):
             first = self._address.index(i) * self._num
@@ -709,7 +703,6 @@ class OscListReceive(PyoObject):
             first = ind * self._num
             for i in reversed(range(first, first+self._num)):
                 obj = self._base_objs.pop(i)
-                obj.deleteStream()
 
     def setInterpolation(self, x):
         """
@@ -757,7 +750,7 @@ class OscListReceive(PyoObject):
             return outlist
 
     def out(self, chnl=0, inc=1, dur=0, delay=0):
-        return self
+        return self.play(dur, delay)
 
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = []
