@@ -21,6 +21,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
+import sys
 from _core import *
 from _maps import *
 from types import StringType, ListType
@@ -293,6 +294,9 @@ class Choice(PyoObject):
     """
     def __init__(self, choice, freq=1., mul=1, add=0):
         PyoObject.__init__(self)
+        if type(choice) != ListType:
+            print >> sys.stderr, 'TypeError: "choice" argument of %s must be a list.\n' % self.__class__.__name__
+            exit()
         self._choice = choice
         self._freq = freq
         self._mul = mul
@@ -830,8 +834,9 @@ class XnoiseMidi(PyoObject):
 
     >>> s = Server().boot()
     >>> s.start()
-    >>> l = Phasor(.1, 0, .5, 0)
-    >>> freq = XnoiseMidi('loopseg', freq=8, x1=1, x2=l, scale=1, mrange=(60,96))
+    >>> l = Phasor(.4)
+    >>> rnd = XnoiseMidi('loopseg', freq=8, x1=1, x2=l, scale=0, mrange=(60,96))
+    >>> freq = Snap(rnd, choice=[0, 2, 3, 5, 7, 8, 11], scale=1)
     >>> jit = Randi(min=0.99, max=1.01, freq=[2.33,3.41])
     >>> a = SineLoop(freq*jit, feedback=0.03, mul=.2).out()
 
