@@ -50,8 +50,14 @@ class Server(object):
     duplex : int {0, 1}, optional
         Input - output mode. 0 is output only and 1 is both ways. 
         Defaults to 1.
-    audio : string {'portaudio', 'pa', 'jack', 'coreaudio', 'offline'}, optional
+    audio : string {'portaudio', 'pa', 'jack', 'coreaudio', 'offline', 'offline_nb}, optional
         Audio backend to use. 'pa' is equivalent to 'portaudio'.
+        'offline' save the audio output in a soundfile as fast as possible in blocking mode, 
+        ie. the main program doesn't respond until the end of the computation.
+        'offline_nb' save the audio output in a soundfile as fast as possible in non-blocking 
+        mode, ie. the computation is executed in a separated thread, allowing the program to
+        respond while the computation goes on. It is the responsibility of the user to make
+        sure that the program doesn't exit before the computation is done.
         Default is 'portaudio'.
     jackname : string, optional
         Name of jack client. Defaults to 'pyo'
@@ -78,6 +84,8 @@ class Server(object):
     getGlobalSeed() : Returns the server's global seed.
     getIsStarted() : Returns 1 if the server is started, otherwise returns 0.
     getMidiActive() : Returns 1 if Midi callback is active, otherwise returns 0.
+    getStreams() : Returns the list of Stream objects currently in the Server memory.
+    getNumberOfStreams() : Returns the number of streams currently in the Server memory.
 
     The next methods must be called before booting the server
 
@@ -495,6 +503,19 @@ class Server(object):
         """
         return self._server.getMidiActive()
 
+    def getStreams(self):
+        """
+        Returns the list of Stream objects currently in the Server memory.
+        
+        """
+        return self._server.getStreams()
+
+    def getNumberOfStreams(self):
+        """
+        Returns the number of streams currently in the Server memory.
+        
+        """
+        return len(self._server.getStreams())
 
     @property
     def amp(self):
