@@ -331,6 +331,8 @@ class ChebyTable(PyoTableObject):
         previously drawn waveform.
     replace(list) : Redraw the waveform according to the new `list` 
         parameter.
+    getNormTable() : Return a DataTable filled with the normalization
+        function corresponding to the current polynomial.
 
     Attributes:
 
@@ -384,10 +386,22 @@ class ChebyTable(PyoTableObject):
             Relative strengths of the fixed harmonic partial 
             numbers 1,2,3, ..., 12. Up to 12 partials can be specified.
 
-        """      
+        """ 
         self._list = list
         [obj.replace(list) for obj in self._base_objs]
 
+    def getNormTable(self):
+        """
+        Return a DataTable filled with the normalization function 
+        corresponding to the current polynomial.
+        
+        """
+        if sum(self._list[1::2]) == 0:
+            data = self._base_objs[0].getNormTable(0)
+        else:
+            data = self._base_objs[0].getNormTable(1)
+        return DataTable(size=len(data), init=data).normalize()
+        
     @property
     def size(self):
         """int. Table size in samples.""" 
@@ -770,6 +784,10 @@ class LinTable(PyoTableObject):
     """
     def __init__(self, list=[(0, 0.), (8191, 1.)], size=8192):
         PyoTableObject.__init__(self)
+        if size < list[-1][0]:
+            print "LinTable warning : size smaller than last point position."
+            print "                   Increased size to last point position + 1"
+            size = list[-1][0] + 1
         self._size = size
         self._base_objs = [LinTable_base(list, size)]
 
@@ -928,6 +946,10 @@ class CosTable(PyoTableObject):
     """
     def __init__(self, list=[(0, 0.), (8191, 1.)], size=8192):
         PyoTableObject.__init__(self)
+        if size < list[-1][0]:
+            print "CosTable warning : size smaller than last point position."
+            print "                   Increased size to last point position + 1"
+            size = list[-1][0] + 1
         self._size = size
         self._base_objs = [CosTable_base(list, size)]
 
@@ -1108,6 +1130,10 @@ class CurveTable(PyoTableObject):
     """
     def __init__(self, list=[(0, 0.), (8191, 1.)], tension=0, bias=0, size=8192):
         PyoTableObject.__init__(self)
+        if size < list[-1][0]:
+            print "CurveTable warning : size smaller than last point position."
+            print "                     Increased size to last point position + 1"
+            size = list[-1][0] + 1
         self._size = size
         self._tension = tension
         self._bias = bias
@@ -1324,6 +1350,10 @@ class ExpTable(PyoTableObject):
     """
     def __init__(self, list=[(0, 0.), (8192, 1.)], exp=10, inverse=True, size=8192):
         PyoTableObject.__init__(self)
+        if size < list[-1][0]:
+            print "ExpTable warning : size smaller than last point position."
+            print "                   Increased size to last point position + 1"
+            size = list[-1][0] + 1
         self._size = size
         self._exp = exp
         self._inverse = inverse
@@ -1484,8 +1514,9 @@ class SndTable(PyoTableObject):
 
     Parameters:
 
-    path : string
-        Full path name of the sound.
+    path : string, optional
+        Full path name of the sound. The defaults, None, creates an empty
+        table.
     chnl : int, optional
         Channel number to read in. Available at initialization time only.
         The default (None) reads all channels.
@@ -1526,7 +1557,7 @@ class SndTable(PyoTableObject):
     >>> a = Osc(table=t, freq=[freq, freq*.995], mul=.3).out()
 
     """
-    def __init__(self, path, chnl=None, start=0, stop=None, initchnls=1):
+    def __init__(self, path=None, chnl=None, start=0, stop=None, initchnls=1):
         PyoTableObject.__init__(self)
         self._path = path
         self._chnl = chnl
@@ -1824,7 +1855,7 @@ class SndTable(PyoTableObject):
         """float. Stop point, in seconds, to read into the file.""" 
         return self._stop
     @stop.setter
-    def stop(self, x): print "'stop' attribute is read-only."
+    def stop(self, x): print "SndTable 'stop' attribute is read-only."
 
 class NewTable(PyoTableObject):
     """
