@@ -24,6 +24,7 @@
 #include <stdarg.h>
 #include <time.h>
 #include <stdlib.h>
+#include <pthread.h>
 
 #include "structmember.h"
 #include "portaudio.h"
@@ -86,6 +87,7 @@ void
 Server_warning(Server *self, char * format, ...)
 {
     // Warnings should be used when an unexpected or unusual choice was made by pyo
+#ifndef NO_MESSAGES
     if (self->verbosity & 4) {
         char buffer[256];
         va_list args;
@@ -94,6 +96,7 @@ Server_warning(Server *self, char * format, ...)
         va_end (args);
         printf("%s",buffer);
     }
+#endif
 }
 
 void
@@ -512,12 +515,13 @@ Server_pa_deinit(Server *self)
     PyoPaBackendData *be_data = (PyoPaBackendData *) self->audio_be_data;
 
     if (Pa_IsStreamActive(be_data->stream) || ! Pa_IsStreamStopped(be_data->stream)) {
-        err = Pa_StopStream(be_data->stream);
-        portaudio_assert(err, "Pa_StopStream");
+        self->server_started = 0;
+        //err = Pa_StopStream(be_data->stream);
+        //portaudio_assert(err, "Pa_StopStream");
     }
     
-    err = Pa_CloseStream(be_data->stream);
-    portaudio_assert(err, "Pa_CloseStream");
+//    err = Pa_CloseStream(be_data->stream);
+//    portaudio_assert(err, "Pa_CloseStream");
     
     err = Pa_Terminate();
     portaudio_assert(err, "Pa_Terminate");
@@ -566,7 +570,7 @@ Server_jack_autoconnect (Server *self)
     int i=0;
     while(ports[i]!=NULL && be_data->jack_in_ports[i] != NULL){
         if (jack_connect (be_data->jack_client, ports[i], jack_port_name(be_data->jack_in_ports[i]))) {
-            Server_warning(self, "Jack: cannot connect input ports\n");
+            Server_error(self, "Jack: cannot connect input ports\n");
             ret = -1;
         }
         i++;
@@ -582,7 +586,7 @@ Server_jack_autoconnect (Server *self)
     i=0;
     while(ports[i]!=NULL && be_data->jack_out_ports[i] != NULL){
         if (jack_connect (be_data->jack_client, jack_port_name (be_data->jack_out_ports[i]), ports[i])) {
-            Server_warning(self, "Jack: cannot connect output ports\n");
+            Server_error(self, "Jack: cannot connect output ports\n");
             ret = -1;
         }
         i++;
@@ -616,7 +620,7 @@ Server_jack_init (Server *self)
         return -1;
     }
     if (status & JackServerStarted) {
-        Server_message(self, "JACK server started.\n");
+        Server_warning(self, "JACK server started.\n");
     }
     if (strcmp(self->serverName, jack_get_client_name(be_data->jack_client)) ) {
         strcpy(self->serverName, jack_get_client_name(be_data->jack_client));
@@ -756,7 +760,7 @@ Server_coreaudio_init(Server *self)
             free(name);
             break;
         }
-        Server_message(self, "   %d : \"%s\"\n", i, name);
+        Server_debug(self, "   %d : \"%s\"\n", i, name);
         free(name);
     }    
     
@@ -786,7 +790,7 @@ Server_coreaudio_init(Server *self)
         if (err != kAudioHardwareNoError) {
             Server_error(self, "Get kAudioDevicePropertyDeviceName error %s A %08X\n", (char*)&err, mInputDevice);
         }
-        Server_message(self, "Coreaudio : Uses input device : \"%s\"\n", name);
+        Server_debug(self, "Coreaudio : Uses input device : \"%s\"\n", name);
         self->input = mInputDevice;
         free(name);
     }    
@@ -813,7 +817,7 @@ Server_coreaudio_init(Server *self)
     if (err != kAudioHardwareNoError) {
         Server_error(self, "Get kAudioDevicePropertyDeviceName error %s A %08X\n", (char*)&err, mOutputDevice);
     }
-    Server_message(self, "Coreaudio : Uses output device : \"%s\"\n", name);
+    Server_debug(self, "Coreaudio : Uses output device : \"%s\"\n", name);
     self->output = mOutputDevice;
     free(name);
     
@@ -880,10 +884,10 @@ Server_coreaudio_init(Server *self)
         if (err != kAudioHardwareNoError)
             Server_error(self, "set kAudioDevicePropertyBufferFrameSize error %4.4s\n", (char*)&err);
         else
-            Server_message(self, "pyo buffer size set to output device buffer size : %i\n", self->bufferSize);
+            Server_debug(self, "pyo buffer size set to output device buffer size : %i\n", self->bufferSize);
     } 
     else
-        Server_message(self, "Coreaudio : Changed output device buffer size successfully: %i\n", self->bufferSize);
+        Server_debug(self, "Coreaudio : Changed output device buffer size successfully: %i\n", self->bufferSize);
 
     if (self->duplex == 1) {
         err = AudioDeviceSetProperty(mInputDevice, &now, 0, false, kAudioDevicePropertyBufferFrameSize, count, &self->bufferSize);
@@ -903,10 +907,10 @@ Server_coreaudio_init(Server *self)
         if (err != kAudioHardwareNoError)
             Server_error(self, "set kAudioDevicePropertyNominalSampleRate error %s\n", (char*)&err);
         else    
-            Server_message(self, "pyo sampling rate set to output device sampling rate : %i\n", self->samplingRate);
+            Server_debug(self, "pyo sampling rate set to output device sampling rate : %i\n", self->samplingRate);
     }
     else
-        Server_message(self, "Coreaudio : Changed output device sampling rate successfully: %.2f\n", self->samplingRate);
+        Server_debug(self, "Coreaudio : Changed output device sampling rate successfully: %.2f\n", self->samplingRate);
     
     if (self->duplex ==1) {
         pyoSamplingRate = self->samplingRate;
@@ -1061,30 +1065,65 @@ Server_coreaudio_stop(Server *self)
 #endif
 
 int
-Server_offline_init (Server *self)
+Server_offline_init(Server *self)
 {
     return 0;
 }
 
 int
-Server_offline_deinit (Server *self)
+Server_offline_deinit(Server *self)
 {
     return 0;
 }
 
-int
-Server_offline_start (Server *self)
+void 
+*Server_offline_thread(void *arg)
 {
+    int numBlocks;
+    Server *self;
+    self = (Server *)arg;
+    
+    if (self->recdur < 0) {
+        Server_error(self,"Duration must be specified for Offline Server (see Server.recordOptions).");
+    }
+    else {
+        Server_message(self,"Offline Server rendering file %s dur=%f\n", self->recpath, self->recdur);
+        numBlocks = ceil(self->recdur * self->samplingRate/self->bufferSize);
+        Server_debug(self,"Number of blocks: %i\n", numBlocks);
+        Server_start_rec_internal(self, self->recpath);
+        while (numBlocks-- > 0 && self->server_stopped == 0) {
+            offline_process_block((Server *) self); 
+        }
+        self->server_started = 0;
+        self->record = 0;
+        sf_close(self->recfile);
+        Server_message(self,"Offline Server rendering finished.\n");         
+    }
+}
+
+int
+Server_offline_nb_start(Server *self)
+{
+    pthread_t offthread;
+    pthread_create(&offthread, NULL, Server_offline_thread, self);
+    return 0;
+}
+
+int
+Server_offline_start(Server *self)
+{
+    int numBlocks;
+    
     if (self->recdur < 0) {
         Server_error(self,"Duration must be specified for Offline Server (see Server.recordOptions).");
         return -1;
     }
     Server_message(self,"Offline Server rendering file %s dur=%f\n", self->recpath, self->recdur);
-    int numBlocks = ceil(self->recdur * self->samplingRate/self->bufferSize);
+    numBlocks = ceil(self->recdur * self->samplingRate/self->bufferSize);
     Server_debug(self,"Number of blocks: %i\n", numBlocks);
     Server_start_rec_internal(self, self->recpath);
     while (numBlocks-- > 0 && self->server_stopped == 0) {
-        offline_process_block((Server *) self);   
+        offline_process_block((Server *) self); 
     }
     self->server_started = 0;
     self->record = 0;
@@ -1094,7 +1133,7 @@ Server_offline_start (Server *self)
 }
 
 int
-Server_offline_stop (Server *self)
+Server_offline_stop(Server *self)
 {
     self->server_stopped = 1;
     return 0;
@@ -1109,7 +1148,6 @@ Server_process_buffers(Server *server)
     float *out = server->output_buffer;    
     MYFLT buffer[server->nchnls][server->bufferSize];
     int i, j, chnl;
-    int count = server->stream_count;
     int nchnls = server->nchnls;
     MYFLT amp = server->amp;
     Stream *stream_tmp;
@@ -1117,7 +1155,7 @@ Server_process_buffers(Server *server)
 
     memset(&buffer, 0, sizeof(buffer));
     PyGILState_STATE s = PyGILState_Ensure();
-    for (i=0; i<count; i++) {
+    for (i=0; i<server->stream_count; i++) {
         stream_tmp = (Stream *)PyList_GET_ITEM(server->streams, i);
         if (Stream_getStreamActive(stream_tmp) == 1) {
             Stream_callFunction(stream_tmp);
@@ -1258,7 +1296,7 @@ Server_shut_down(Server *self)
     int i;
     int ret = -1;
     if (self->server_booted == 0) {
-        Server_error(self, "The Server must be booted!");
+        Server_error(self, "The Server must be booted!\n");
         Py_INCREF(Py_None);
         return Py_None;
     }
@@ -1287,6 +1325,9 @@ Server_shut_down(Server *self)
         case PyoOffline:
             ret = Server_offline_deinit(self);  
             break;         
+        case PyoOfflineNB:
+            ret = Server_offline_deinit(self);  
+            break;         
     }
     self->server_booted = 0;
     if (ret < 0) {
@@ -1319,10 +1360,13 @@ Server_clear(Server *self)
 static void
 Server_dealloc(Server* self)
 {  
-    Server_shut_down(self);
+    if (self->server_booted == 1)
+        Server_shut_down(self);
     Server_clear(self);
     free(self->input_buffer);
+    free(self->output_buffer);
     free(self->serverName);
+    my_server = NULL;
     self->ob_type->tp_free((PyObject*)self);
 }
 
@@ -1358,7 +1402,6 @@ Server_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->startoffset = 0.0;
     self->globalSeed = 0;
     Py_XDECREF(my_server);
-    Py_XINCREF(self);
     my_server = (Server *)self;
     return (PyObject *)self;
 }
@@ -1387,6 +1430,9 @@ Server_init(Server *self, PyObject *args, PyObject *kwds)
     else if (strcmp(audioType, "offline") == 0) {
         self->audio_be_type = PyoOffline;
     } 
+    else if (strcmp(audioType, "offline_nb") == 0) {
+        self->audio_be_type = PyoOfflineNB;
+    } 
     else {
         Server_warning(self, "Unknown audio type. Using Portaudio\n");
         self->audio_be_type = PyoPortaudio;
@@ -1398,10 +1444,10 @@ Server_init(Server *self, PyObject *args, PyObject *kwds)
     self->recpath = getenv("HOME");
     if (self->recpath != NULL)
         strncat(self->recpath, "/pyo_rec.wav", strlen("/pyo_rec.wav")); 
+
     return 0;
 }
 
-
 static PyObject *
 Server_setInputDevice(Server *self, PyObject *arg)
 {
@@ -1778,6 +1824,12 @@ Server_boot(Server *self)
                 Server_offline_deinit(self);
             }
             break;
+        case PyoOfflineNB:
+            audioerr = Server_offline_init(self);
+            if (audioerr < 0) {
+                Server_offline_deinit(self);
+            }
+            break;
     }
     // Must allocate buffer after initializing the audio backend in case parameters change there
     if (self->input_buffer) {
@@ -1820,6 +1872,8 @@ Server_start(Server *self)
     }
     int err = -1;
     
+    Server_debug(self, "Number of streams %d\n", self->stream_count);
+
     /* Ensure Python is set up for threading */
     PyEval_InitThreads();
 
@@ -1857,9 +1911,12 @@ Server_start(Server *self)
         case PyoOffline:
             err = Server_offline_start(self);
             break;           
+        case PyoOfflineNB:
+            err = Server_offline_nb_start(self);
+            break;           
     }
     if (err) {
-        Server_error(self, "Error starting server.");
+        Server_error(self, "Error starting server.\n");
     }
 
     Py_INCREF(Py_None);
@@ -1892,6 +1949,9 @@ Server_stop(Server *self)
         case PyoOffline:
             err = Server_offline_stop(self);
             break;    
+        case PyoOfflineNB:
+            err = Server_offline_stop(self);
+            break;    
     }
 
     if (err < 0) {
@@ -2011,11 +2071,10 @@ Server_addStream(Server *self, PyObject *args)
         return PyInt_FromLong(-1); 
         
     if (tmp == NULL) {
-        Server_error(self, "Need a pyo object as argument\n");
+        Server_error(self, "Server_addStream needs a pyo object as argument.\n");
         return PyInt_FromLong(-1);
     }
 
-    Py_INCREF(tmp);
     PyList_Append(self->streams, tmp);
 
     self->stream_count++;
@@ -2037,8 +2096,10 @@ Server_removeStream(Server *self, int id)
             Server_debug(self, "Removed stream id %d\n", id);
             PySequence_DelItem(self->streams, i);
             self->stream_count--;
+            break;
         }
     }
+
     Py_INCREF(Py_None);
     return Py_None;    
 }
@@ -2157,8 +2218,8 @@ static PyMethodDef Server_methods[] = {
     {"setDuplex", (PyCFunction)Server_setDuplex, METH_O, "Sets the server's duplex mode (0 = only out, 1 = in/out)."},
     {"setGlobalSeed", (PyCFunction)Server_setGlobalSeed, METH_O, "Sets the server's global seed for random objects."},
     {"setAmp", (PyCFunction)Server_setAmp, METH_O, "Sets the overall amplitude."},
-    {"setAmpCallable", (PyCFunction)Server_setAmpCallable, METH_O, "Sets the Server's GUI object."},
-    {"setTimeCallable", (PyCFunction)Server_setTimeCallable, METH_O, "Sets the Server's TIME object."},
+    {"setAmpCallable", (PyCFunction)Server_setAmpCallable, METH_O, "Sets the Server's GUI callable object."},
+    {"setTimeCallable", (PyCFunction)Server_setTimeCallable, METH_O, "Sets the Server's TIME callable object."},
     {"setVerbosity", (PyCFunction)Server_setVerbosity, METH_O, "Sets the verbosity."},
     {"setStartOffset", (PyCFunction)Server_setStartOffset, METH_O, "Sets starting time offset."},
     {"boot", (PyCFunction)Server_boot, METH_NOARGS, "Setup and boot the server."},
